[PATCH 1 of 7] copies: rename m1 to msrc

Stanislau Hlebik stash at fb.com
Mon May 29 13:11:57 UTC 2017


# HG changeset patch
# User Stanislau Hlebik <stash at fb.com>
# Date 1496062335 25200
#      Mon May 29 05:52:15 2017 -0700
# Node ID 75f0d8342109877a0dd620df3f566d0f080a9138
# Parent  c2b7fb580794ccbe21fa8c47f493eff6e9431fee
copies: rename m1 to msrc

Small refactoring that renames `m1` parameter name to a more clearer name
`msrc`.

diff --git a/mercurial/copies.py b/mercurial/copies.py
--- a/mercurial/copies.py
+++ b/mercurial/copies.py
@@ -598,13 +598,13 @@
     except StopIteration:
         return False
 
-def _checkcopies(ctx, f, m1, m2, base, tca, remotebase, limit, data):
+def _checkcopies(ctx, f, msrc, m2, base, tca, remotebase, limit, data):
     """
     check possible copies of f from m1 to m2
 
-    ctx = starting context for f in m1
-    f = the filename to check (as in m1)
-    m1 = the source manifest
+    ctx = starting context for f in srcm
+    f = the filename to check (as in msrc)
+    msrc = the source manifest
     m2 = the destination manifest
     base = the changectx used as a merge base
     tca = topological common ancestor for graft-like scenarios
@@ -632,13 +632,13 @@
     backwards = not remotebase and base != tca and f in mb
     getfctx = _makegetfctx(ctx)
 
-    if m1[f] == mb.get(f) and not remotebase:
+    if msrc[f] == mb.get(f) and not remotebase:
         # Nothing to merge
         return
 
     of = None
     seen = {f}
-    for oc in getfctx(f, m1[f]).ancestors():
+    for oc in getfctx(f, msrc[f]).ancestors():
         ocr = oc.linkrev()
         of = oc.path()
         if of in seen:
@@ -598,13 +598,13 @@
     """
-    check possible copies of f from m1 to m2
+    check possible copies of f from msrc to m2
 


More information about the Mercurial-devel mailing list